import request from '@/utils/request'
import qs from 'qs'
import { getLocalforage, getEnv, getAPI } from '@/utils'
import { config } from '@/utils/constant'
import axios from 'axios'

/**
 * 获取项目配置(动态主题)
 */
export async function getProjectConfigProvider({ serviceCode = 'cloud_card', pid, orgId }) {
  let timestamp = Number(new Date())
  const apiPrefix = `${getAPI()}/pcm/project_config`

  try {
    const api = `${apiPrefix}/${pid}`
    const res = await axios.get(`${api}/${serviceCode}.json?timestamp=${timestamp}`)

    return {
      ...res.data.data,
      assetsPath: `${api}/services/${serviceCode}`,
    }
  } catch (err) {
    try {
      const api = `${apiPrefix}/${pid}/${orgId}`
      const res = await axios.get(`${api}/${serviceCode}.json?timestamp=${timestamp}`)

      return {
        ...res.data.data,
        assetsPath: `${api}/services/${serviceCode}`,
      }
    } catch (error) {
      const api = `${apiPrefix}/default`

      return {
        theme: config.theme,
        assetsPath: `${api}/services/${serviceCode}`,
      }
    }
  }
}

/**
 * 初始化超级云卡
 */
export function cloud_card(data) {
  return request({
    url: `/api/wechat/front/cloud_card`,
    method: 'post',
    data,
  })
}

/**
 * 云卡有效期查询（查询）
 */
export function cloud_cardTtl(data) {
  return request({
    url: `/api/wechat/front/cloud_card/ttl?${qs.stringify(data)}`,
    method: 'post',
    data,
  })
}

/**
 * apiUserInfo
 */
export function apiUserInfo(data) {
  return request({
    url: `/api/wechat/front/userInfos`,
    method: 'post',
    data: qs.stringify(data),
  })
}

/**
 * logout
 */
export function logout(data) {
  return request({
    url: `/api/wechat/front/logout`,
    method: 'post',
    data: qs.stringify(data),
  })
}

/**
 * 获取微信 JS-SDK 接口配置所需参数
 */
export function getFenXiang(data) {
  return request({
    url: `/api/wechat/front/common/fenxiang`,
    method: 'post',
    data: qs.stringify(data),
  })
}

/**
 * 注入微信 JS-SDK 接口权限验证配置信息
 */
export function getWxConfig() {
  return new Promise((resolve, reject) => {
    if (getEnv().isInWeixinApp) {
      const params = {
        url: location.href.split('#')[0],
        publicId: getLocalforage('pid'),
      }

      getFenXiang(params).then((res) => {
        const { appid, timestamp, nonceStr, signature } = JSON.parse(res.data || JSON.stringify({}))

        wx.config({
          debug: false, // 开启调试模式
          appId: appid, // 必填，公众号的唯一标识
          timestamp: timestamp, // 必填，生成签名的时间戳
          nonceStr: nonceStr, // 必填，生成签名的随机串
          signature: signature, // 必填，签名，见附录1
          jsApiList: ['getLocation', 'hideMenuItems', 'hideOptionMenu', 'closeWindow', 'scanQRCode'], // 必填，需要使用的JS接口列表，所有JS接口列表见附录2
        })

        wx.ready(() => {
          resolve()
        })

        wx.error((err) => {
          reject(err)
        })
      })
    } else {
      console.warn('不在微信网页内打开，不进行微信签名权限验证！')
      resolve()
    }
  })
}

export default {
  cloud_card,
  cloud_cardTtl,
  apiUserInfo,
  logout,
  // 微信签名
  getFenXiang,
  getWxConfig,
}
