import router from '@/router'
import store from '@/store'
import { getURLParameters, getEnv, idDefString, setLocalforage } from '@/utils'
import { getWxConfig } from '@/apis'

window.appOptions = {} // 应用入参缓存
window.appLoadedFlag = false // 应用窗口加载标记

router.beforeEach(async (to, from, next) => {
  console.log('[route]', from.path, to.path)
  // add route title
  const title = to.meta && to.meta.title
  if (title) {
    document.title = title
  }
  // 应用窗口加载

  if (!window.appLoadedFlag) {
    window.appLoadedFlag = true
    console.info('app onLaunch')
    console.info('app version', process.env.APP_VERSION)
    console.info('app URL', window.location.href)
    console.info(
      '[用户信息] 设备信息: 是否安卓',
      getEnv().isAndroid,
      '是否IOS',
      getEnv().isIOS,
      '是否微信内打开',
      getEnv().isInWeixinApp,
      '是否小程序内打开',
      getEnv().isInMiniProgram,
    )
    // 应用入参
    refreshAppOptions()
    setWeiXinPublicStorage(window.appOptions)
    const { pid, orgId, userToken } = window.appOptions

    await store.dispatch('getServiceConfigProvider', {
      orgId,
      pid,
    })
    // 登录
    if (userToken) {
      store.commit('login', { token: userToken })
    }
  }

  if (process.env.NODE_ENV === 'production') {
    const needWxConfig = to.meta && to.meta.needWxConfig
    if (String(needWxConfig) !== 'false') {
      getWxConfig().then(() => {
        console.info(`page path ${to.path} wxConfig ready`)
        wx.hideOptionMenu()
      })
    }
  }

  next()
})

/**
 * 更新应用参数
 * @param {*} to
 * @param {*} from
 */
function refreshAppOptions() {
  const urlOptions = getURLParameters()
  console.info('app URL Parameters', urlOptions)
  let query = {}
  // 处理字段名不统一
  const pid = urlOptions.state || urlOptions.pid || urlOptions.publicId
  const openId = urlOptions.openId || urlOptions.openid
  if (pid) {
    urlOptions.pid = pid
  }
  if (openId) {
    urlOptions.openId = openId
  }

  Object.keys(urlOptions).forEach((key) => {
    if (idDefString(urlOptions[key])) {
      query[key] = urlOptions[key]
    }
  })

  console.info('app options', query)
  window.appOptions = query
}

/**
 * 设置微信公众号缓存
 */
function setWeiXinPublicStorage(query) {
  // pid
  if (query.pid) {
    setLocalforage('pid', query.pid)
  }
  // openId
  if (query.openId) {
    setLocalforage('openId', query.openId)
  }
  // orgId
  if (query.orgId) {
    setLocalforage('orgId', query.orgId)
  }
  // channel
  if (query.channel) {
    setLocalforage('channel', query.channel)
  }
}
