import Vue from 'vue'
import VueRouter from 'vue-router'

Vue.use(VueRouter)

// 解决路由在 push/replace 了相同地址报错的问题
const originalPush = VueRouter.prototype.push
VueRouter.prototype.push = function push(location) {
  return originalPush.call(this, location).catch((err) => err)
}
const originalReplace = VueRouter.prototype.replace
VueRouter.prototype.replace = function replace(location) {
  return originalReplace.call(this, location).catch((err) => err)
}

const routes = [
  {
    path: '/',
    redirect: '/home',
  },
  {
    path: '/home',
    name: 'homeIndex',
    component: () => import(/* webpackChunkName: "manifest" */ '@/views/home/index.vue'),
    meta: {
      title: '首页',
    },
  },
  // errorPage
  {
    path: '/reload',
    component: () => import(/* webpackChunkName: "manifest" */ '@/views/error-page/reload.vue'),
    meta: {
      title: '加载异常',
    },
  },
  {
    path: '/404',
    component: () => import(/* webpackChunkName: "manifest" */ '@/views/error-page/404.vue'),
    meta: {
      title: '404',
    },
  },
  // 404 Not found
  { path: '*', redirect: '/404' },
]

const router = new VueRouter({
  routes,
  scrollBehavior(to, from, savedPosition) {
    if (savedPosition) {
      return savedPosition
    } else {
      return { x: 0, y: 0 }
    }
  },
})

export default router
