import Vue from 'vue'
import Vuex from 'vuex'
import { fromCamelCase, appendCss } from '@/utils'
import { getProjectConfigProvider } from '@/apis'

Vue.use(Vuex)

export default new Vuex.Store({
  state: {
    manifest: {
      theme: {},
    },
    token: '',
  },
  getters: {
    manifest: (state) => {
      return state.manifest
    },
    theme: (state) => {
      return state.manifest.theme
    },
  },
  mutations: {
    saveManifest(state, data) {
      state.manifest = data
    },
    login(state, data = {}) {
      state.token = data.token
    },
    logout(state, data) {
      state.token = ''
    },
  },
  actions: {
    /**
     * 获取项目个性化配置
     */
    async getServiceConfigProvider({ commit }, params) {
      return await getProjectConfigProvider(params).then((res) => {
        const { theme } = res
        // theme
        const colors = {}
        Object.keys(theme).forEach((v) => {
          colors[fromCamelCase(v, '-')] = theme[v]
        })

        const cssList = Object.keys(colors).map((key) => `--${key}: ${colors[key]};`)
        const cssText = `:root { ${cssList.join('\n')} }`

        appendCss(cssText, 'theme', true)

        commit('saveManifest', res)
        return res
      })
    },
  },
})
