import axios from 'axios'
import { Toast } from 'vant'
import store from '@/store'
// import router from '@/router'
import { getAPI, throttle } from '@/utils'

/**
 * 单独处理轮询请求，频繁触发只显示一次提示
 */
const throttleHttpErrorFn = throttle(httpErrorHandle, 10000)

// create an axios instance
const instance = axios.create({
  baseURL: getAPI(),
  timeout: 5000,
  withCredentials: false,
})

// 设置post请求头
instance.defaults.headers.post['Content-Type'] = 'application/x-www-form-urlencoded;charset=UTF-8'

/**
 * 请求拦截器
 */
instance.interceptors.request.use((request) => {
  store.state.token && (request.headers.userToken = store.state.token)
  return request
})

/**
 * 响应拦截器
 */
instance.interceptors.response.use(
  (response) => {
    const result = response.data
    const { code } = result
    if (Number(code) === 200) {
      return Promise.resolve(result)
    } else {
      errorResultMessage(result)
      return Promise.reject(result)
    }
  },
  (error) => {
    if (['/api/wechat/front/cloud_card/ttl'].some((v) => error.config.url.includes(v))) {
      throttleHttpErrorFn(error)
    } else {
      httpErrorHandle(error)
    }

    return Promise.reject(error)
  },
)

/**
 * 业务错误
 */
function errorResultMessage(res) {
  const { code, msg } = res
  if (Number(code) === 401) {
    Toast.clear()
    store.commit('logout')
    goLogin()
  } else {
    Toast({
      message: msg || 'Result Error',
      duration: 1000 * 5,
    })
  }
}

/**
 * HTTP 错误
 */
function httpErrorHandle(error) {
  // console.log('[httpErrorHandle]', error);
  // console.log('[httpErrorHandle]', error.toString());

  let msg = ''

  if (error.response) {
    const { status } = error.response

    switch (status) {
      case 403:
        msg = `${status} 网络请求被拒绝`
        break
      case 404:
        msg = `${status} 网络请求不存在`
        break
      case 500:
        msg = `${status} 服务器内部错误`
        break
      default:
        msg = `${status || error.message}`
        break
    }
  }

  if (error.message.includes('timeout')) {
    msg = '请求超时'
  }

  if (error.message.includes('Network Error')) {
    msg = '当前网络不可用，请检查你的网络设置'
  }

  Toast({
    message: msg || error.toString(),
    duration: 1000 * 5,
  })
}

/**
 * 跳转登录页面 无
 */
function goLogin() {
  // console.log('跳转登录页')
  // router.replace('/login')
}

export default instance
